pub enum UsbEndpointType {
Bulk,
Interrupt,
Isochronous,
}Expand description
USB endpoint type.
Variants
Bulk
Provides reliable data transfer for large payloads.
Data sent through a bulk endpoint is guaranteed to be delivered or generate an error but may be preempted by other data traffic.
Interrupt
Provides reliable data transfer for small payloads.
Data sent through an interrupt endpoint is guaranteed to be delivered or generate an error and is also given dedicated bus time for transmission.
Isochronous
Provides unreliable data transfer for payloads that must be delivered periodically.
They are given dedicated bus time but if a deadline is missed the data is dropped.